%define __provides_exclude_from ^%{_libdir}/recoll/librecoll\\.so.*$
%define __requires_exclude      ^librecoll\\.so.*$
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

Name:           recoll
Version:        1.22.3
Release:        %mkrel 2
Summary:        Desktop full text search tool with a Qt GUI
URL:            http://www.lesbonscomptes.com/recoll/
Group:          Databases
License:        GPLv2
Source0:        http://www.lesbonscomptes.com/recoll/%{name}-%{version}.tar.gz
BuildRequires:  xapian-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  bison-devel-static
BuildRequires:  extra-cmake-modules
Requires:       xapian

%description
Recoll is a personal full text search package for Linux, FreeBSD and
other Unix systems. It is based on a very strong backend (Xapian), for
which it provides an easy to use, feature-rich, administration
interface.

#------------------------------------------------------
%package -n %{name}-extra
Summary:        Recoll extra indexing packages
Group:          File tools
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
Recommends:     antiword
Recommends:     aspell-en
Recommends:     catdoc
Recommends:     djvulibre
Recommends:     libwpd-tools
Recommends:     mutagen
Recommends:     perl-Image-ExifTool
Recommends:     poppler
Recommends:     pstotext
Recommends:     python
Recommends:     python-chm
Recommends:     python-midi
Recommends:     python-pylzma
Recommends:     python-rarfile
Recommends:     texlive
Recommends:     unrar
Recommends:     unrtf
Recommends:     unzip
Recommends:     xsltproc

%description -n %{name}-extra
This package contains a list of packages' suggestions
for indexing various file types by recoll:

* antiword for MS Word files.
* catdoc for MS Excel and PowerPoint files.
* unrtf for RTF files.
* djvulibre (djvutxt djvused) for djvu files.
* libwpd-tools for Wordperfect files.
* Midi karaoke files need Python and the Midi module
* mutagen for all audio file types.
* perl-Image-ExifTool to extract tag informations:
    This is only of interest if you store personal tags
    or textual descriptions inside the image files.
* python-chm: for microsoft help format files.
* Zip archives need Python (and the standard zipfile module).
* Rar archives need Python, the rarfile Python module and the unrar utility.
* 7zip archives (needs Python and the pylzma module)
* Poopler(pdftotext) for PDF files.
* pstotext for Postscript files.
* texlive :
    detex for TeX files.
    dvips for div files.
* unzip and xsltproc for LibreOffice files.
* xsltproc for MS Open XML (docx).

#-------------------------------------------------------
%package -n python-%{name}
Summary:        Python extension module for recoll
Group:          Development/Python

BuildRequires:  pkgconfig(python)
BuildRequires:  python-setuptools
Requires:       python
Requires:       %{name} = %{version}-%{release}

%description -n python-%{name}
Recoll Python programming interface, for searching and indexing.

#--------------------------------------------------------
%package -n kio-%{name}
Summary:        KIO slave for %{name}
Group:          Graphical desktop/KDE

BuildRequires:  cmake
BuildRequires:  kdepimlibs-devel

Requires:       %{name} = %{version}-%{release}
Requires:       plasma-framework

%description -n kio-%{name}
KIO slave for %{name}. Enables to perform queries and extract
results in Konqueror and Dolphin.

#-------------------------------------------------------
%package -n %{name}-full
Summary:        Full Recoll installation
Group:          Office/Utilities
BuildArch:      noarch

Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-extra = %{version}-%{release}
Requires:       python-%{name} = %{version}-%{release}
Requires:       kio-%{name} = %{version}-%{release}

%description -n %{name}-full
This packages provides the complete recoll installation:

* recoll: The main application
* recoll-extra: Recoll extra indexing packages
* python-recol: Python extension module for recoll
* kio-recoll: KDE KIO slave for recoll
* plasma-runner-recoll: KDE krunner plugin for recoll
#------------------------------------------------------

%prep
%setup -q

%build
%configure2_5x \
    QMAKE=%{_qt5_bindir}/qmake
%make_build

%install
%makeinstall_std

# Remove library to avoid dynamic linkinkg
# when compiling kio recoll.
# The linking made kio recoll non functional
%__rm -f lib/librecoll.so*

pushd kde/kioslave/kio_recoll
%cmake
make
%makeinstall_std
popd

# Add translations tags
(cd %{buildroot} && find . -name '*.qm') | sed -e 's|^.||' | sed -e \
    's:\(.*/translations/\)\([a-z]\+_\)\([a-zA-Z_]\+\)\(\.qm\):%lang(\3) \1\2\3\4:' \
        >> %{name}.lang

%files -f %{name}.lang
%doc README
%{_bindir}/*
%{_datadir}/applications/recoll-searchgui.desktop
%{_datadir}/pixmaps/recoll.png
%{_datadir}/%{name}
%{_iconsdir}/hicolor/48x48/apps/recoll.png
%{_mandir}/man1/recoll*
%{_mandir}/man5/recoll*
%{_libdir}/recoll/
%{_datadir}/appdata/recoll.appdata.xml

#-------------------------------------------------------
%files -n %{name}-extra
#none

#------------------------------------------------------
%files -n python-%{name}
%{python_sitearch}/recoll/
%{python_sitearch}/Recoll-1.0-py%pyver.egg-info

#-------------------------------------------------------
%files -n kio-%{name}
%dir %{_datadir}/kio_recoll
%{_libdir}/qt5/plugins/kio_recoll.so
%{_datadir}/kio_recoll/help.html
%{_datadir}/kio_recoll/welcome.html
%{_datadir}/kservices5/recoll.protocol
%{_datadir}/kservices5/recollf.protocol

#-------------------------------------------------------
%files -n %{name}-full
# none


%changelog
* Fri Nov 04 2016 ghibo <ghibo> 1.22.3-2.mga6
+ Revision: 1065233
- Update to release 1.22.3.

* Fri May 06 2016 dglent <dglent> 1.21.6-1.mga6
+ Revision: 1009687
- Version 1.21.6
- KF5 for kio slave

  + daviddavid <daviddavid>
    - use new python macros

* Thu Jan 21 2016 dglent <dglent> 1.21.4-1.mga6
+ Revision: 926186
- Version 1.21.4
- Add python-pylzma in recommends mga#17546

* Sun Nov 08 2015 dglent <dglent> 1.21.3-1.mga6
+ Revision: 898881
- Version 1.21.3

* Thu Aug 27 2015 cjw <cjw> 1.20.6-3.mga6
+ Revision: 870117
- rebuild with gcc 5

* Thu Jun 25 2015 dglent <dglent> 1.20.6-2.mga6
+ Revision: 842990
- Add BR Qt5WebKitWidgets
  Force Qt5 build

* Mon Jun 22 2015 dglent <dglent> 1.20.6-1.mga6
+ Revision: 839919
- Version 1.20.6
  Qt5 build

* Wed Oct 15 2014 umeabot <umeabot> 1.19.14p2-4.mga5
+ Revision: 750066
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.19.14p2-3.mga5
+ Revision: 730088
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.19.14p2-2.mga5
+ Revision: 688633
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Sat Jul 26 2014 dglent <dglent> 1.19.14p2-1.mga5
+ Revision: 656590
- New version 1.19.14p2

  + pterjan <pterjan>
    - Rebuild for new Python

* Sun May 11 2014 dglent <dglent> 1.19.13-1.mga5
+ Revision: 621947
- New version 1.19.13

* Mon Apr 21 2014 dglent <dglent> 1.19.12p1-1.mga5
+ Revision: 617217
- New version 1.19.12p1
- Find translations and add tags with sed

* Fri Dec 20 2013 dglent <dglent> 1.19.11p1-2.mga4
+ Revision: 559046
- Prevent linking lib with kio-recoll (brakes the application)

* Wed Dec 18 2013 dglent <dglent> 1.19.11p1-1.mga4
+ Revision: 558415
- Fix typos in descriptions
- Exclude library from provides
- Exclude library from requires
- Exclude python library from provides
- Add Requires qt4-common
- Add BR zlib-devel
- Add package recoll-extra
- Add package python-recoll
- Add package recoll-full
- Add lang tags
- Remove surplus in %%setup
- New version 1.19.11p1
- Revert no needed now changes for kio-recoll and library linking (rev#552031)
- Cosmetic change in snippets separators
- Convert tabs to spaces
- Fix some grammar typos in descriptions
- Add %%dir in files
- Add %%doc in kio-recoll
- Fix not working of kio-recoll since v1.19
- Cosmetic chnages in SPEC
- New version 1.19.9
- New version 1.19.9
- New version 1.19.5
- Add requires in kio package
- Remove copy of gpl license
- New version 1.19.4
- Add docs in spec

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.18.1-2.mga3
+ Revision: 380265
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 05 2012 dglent <dglent> 1.18.1-1.mga3
+ Revision: 314471
- New version 1.18.1

* Sun Sep 30 2012 dglent <dglent> 1.17.3-2.mga3
+ Revision: 300817
- Fix kio slave package non build
- Add kio slave package
- Spec cleanup
- Change license to GPLv2

* Sat Jun 02 2012 fwang <fwang> 1.17.3-1.mga3
+ Revision: 253265
- disable python module
- br python
- add br
- new version 1.17.3

* Fri Dec 30 2011 supp <supp> 1.16.2-1.mga2
+ Revision: 189028
- update to 1.16.2

* Fri Oct 07 2011 fwang <fwang> 1.16.1-1.mga2
+ Revision: 152724
- new version 1.16.1

* Wed Sep 28 2011 supp <supp> 1.16.0-1.mga2
+ Revision: 149922
- fix package group
- imported package recoll

